<?php
/*
Plugin Name: MotoPress Google Maps Addon
Plugin URI: https://motopress.com/
Description: Google Maps addon with multiple custom markers, map styles, directions, descriptions, images and links.
Version: 1.4.2
Author: MotoPress
Author URI: https://motopress.com/
Text Domain: mpce-gma
License: GPL2 or later
*/

global $wp_version;
if (version_compare($wp_version, '3.9', '<') && isset($network_plugin)) {
	define('MPCE_GMA_PLUGIN_FILE', $network_plugin);
} else {
	define('MPCE_GMA_PLUGIN_FILE', __FILE__);
}
define('MPCE_GMA_PLUGIN_DIR', trailingslashit(plugin_dir_path(MPCE_GMA_PLUGIN_FILE)));

require_once ABSPATH . 'wp-admin/includes/plugin.php';
require_once MPCE_GMA_PLUGIN_DIR . 'inc/license.php';
require_once MPCE_GMA_PLUGIN_DIR . 'inc/settings.php';
require_once MPCE_GMA_PLUGIN_DIR . 'inc/translations.php';
require_once MPCE_GMA_PLUGIN_DIR . 'inc/mpLibrary.php';
require_once MPCE_GMA_PLUGIN_DIR . 'inc/shortcodes.php';
require_once MPCE_GMA_PLUGIN_DIR . 'inc/simpleShortcodes.php';
require_once MPCE_GMA_PLUGIN_DIR . 'inc/settingsPage.php';
require_once MPCE_GMA_PLUGIN_DIR . 'inc/EDD_MPCE_GMA_Plugin_Updater.php';

function mpceGMALoadTextdomain() {
    load_plugin_textdomain('mpce-gma', FALSE, MPCE_GMA_PLUGIN_NAME . '/lang/');
}
add_action('plugins_loaded', 'mpceGMALoadTextdomain');

function mpceGMAAdminInit() {
    new EDD_MPCE_GMA_Plugin_Updater(MPCE_GMA_EDD_STORE_URL, __FILE__, array(
	    'version' => MPCE_GMA_VERSION,                       // current version number
	    'license' => get_option('edd_mpce_gma_license_key'), // license key (used get_option above to retrieve from DB)
	    'item_id' => MPCE_GMA_EDD_ITEM_ID,                   // id of this plugin
	    'author'  => MPCE_GMA_AUTHOR                         // author of this plugin
    ));
}
add_action('admin_init', 'mpceGMAAdminInit');

function mpceGMASettingsInit($hookSuffix) {
	add_filter('admin_mpce_settings_tabs', 'mpceGMASettingsTab');
	add_action('admin_mpce_settings_save-' . MPCE_GMA_PLUGIN_SHORT_NAME, 'mpceGMASettingsSave');
//    add_action('admin_mpce_settings_print_styles-' . MPCE_GMA_PLUGIN_SHORT_NAME, 'mpceGMASettingsStyles');
}
add_action('admin_mpce_settings_init', 'mpceGMASettingsInit');

function mpceGMALicenseInit($hookSuffix) {
    global $gmaLicense;
	add_filter('admin_mpce_license_tabs', 'mpceGMALicenseTab');
	add_action('admin_mpce_license_save-' . MPCE_GMA_PLUGIN_SHORT_NAME, array(&$gmaLicense, 'save'));
}
add_action('admin_mpce_license_init', 'mpceGMALicenseInit');

function mpceGMAEnqueueScripts() {
	$settings = get_option('mpce-gma-settings', array());
	$browserApiKey = (isset($settings['browser_api_key']) && $settings['browser_api_key']) ? '&key=' . $settings['browser_api_key'] : '';
	$mpceActive = is_plugin_active('motopress-content-editor/motopress-content-editor.php') || is_plugin_active('motopress-content-editor-lite/motopress-content-editor.php');
	$isEditor = $mpceActive && method_exists('MPCEShortcode', 'isContentEditor') && MPCEShortcode::isContentEditor();

	wp_register_style('mpce-gma-style', MPCE_GMA_PLUGIN_DIR_URL . 'assets/css/style.css', array(), MPCE_GMA_VERSION);

//	wp_register_script('googlemapapis', 'https://maps.googleapis.com/maps/api/js?v=3' . $browserApiKey, array(), false, true);
	wp_register_script('googlemapapis', 'https://maps.googleapis.com/maps/api/js?' . $browserApiKey, array(), false, true);
	wp_register_script('googlemap-fontawesome-markers', MPCE_GMA_PLUGIN_DIR_URL . 'vendor/markerwithlabel/markerwithlabel_packed.js', array('googlemapapis'), '1.1.10', true);
    wp_register_script('mpce-gma-script', MPCE_GMA_PLUGIN_DIR_URL . 'assets/js/script.js', array('jquery', 'googlemapapis'), MPCE_GMA_VERSION, true);

	if ($isEditor) {
		wp_register_style('mpce-gma-editor', MPCE_GMA_PLUGIN_DIR_URL . 'assets/css/editor.css', array(), MPCE_GMA_VERSION);

		wp_enqueue_style('mpce-gma-editor');
	}

	if ($isEditor){
		wp_enqueue_style('mpce-gma-style');
		wp_enqueue_script('googlemap-fontawesome-markers');
		wp_enqueue_script('googlemapapis');
		wp_enqueue_script('mpce-gma-script');
	}
	$jsVars = array(
		'ajax_url' => admin_url('admin-ajax.php'),
		'lang' => mpceGMAGetLangStrings(),
        'nonces' => array()
	);
	wp_localize_script('mpce-gma-script', 'MPCE_GMA', $jsVars);
}
add_action('wp_enqueue_scripts', 'mpceGMAEnqueueScripts');

// Plugin Activation
function motopressGMAInstall($network_wide) {
    $autoLicenseKey = apply_filters('gma_auto_license_key', false);        
    if ($autoLicenseKey) {          
        GMALicense::setAndActivateLicenseKey($autoLicenseKey);
    }
}
register_activation_hook(__FILE__, 'motopressGMAInstall');
